'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const kissfs_1 = require("kissfs");
const stylable_1 = require("stylable");
const provider_1 = require("./provider");
function createProvider(stylable, tsLangService, withFilePrefix = true) {
    return new provider_1.default(stylable, tsLangService);
}
exports.createProvider = createProvider;
let legacyBehvior = true;
function toggleLegacy(value) {
    legacyBehvior = value;
}
exports.toggleLegacy = toggleLegacy;
const isWindows = process.platform === 'win32';
function createFs(fileSystem) {
    return {
        readFileSync(path) {
            path = (!legacyBehvior && isWindows) ? `/${path.slice(path.lastIndexOf(':') + 1).replace(/\\/g, '/')}` : path;
            return fileSystem.loadTextFileSync(path).toString();
        },
        statSync(path) {
            path = (!legacyBehvior && isWindows) ? `/${path.slice(path.lastIndexOf(':') + 1).replace(/\\/g, '/')}` : path;
            let isFile = kissfs_1.checkExistsSync('file', fileSystem, path);
            return {
                isDirectory() {
                    return !isFile;
                },
                isFile() {
                    return isFile;
                },
                mtime: new Date(Date.now())
            };
        },
        readlinkSync(_path) {
            return null;
        }
    };
}
exports.createFs = createFs;
function createProcessor(fileSystem) {
    let proccesor = stylable_1.cachedProcessFile((fullpath, content) => {
        return stylable_1.process(stylable_1.safeParse(content, { from: fullpath }));
    }, createFs(fileSystem));
    return proccesor;
}
exports.createProcessor = createProcessor;
//# sourceMappingURL=provider-factory.js.map