"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const VCL = require("vscode-css-languageservice");
const vscode_languageserver_types_1 = require("vscode-languageserver-types");
const provider_1 = require("../lib/provider");
function readDocRange(doc, rng) {
    let lines = doc.getText().split('\n');
    return lines[rng.start.line].slice(rng.start.character, rng.end.character);
}
/**
 * the API for "normal" css language features fallback
 */
class CssService {
    constructor(fs) {
        this.fs = fs;
        this.inner = VCL.getCSSLanguageService();
    }
    getCompletions(document, position) {
        const cssCompsRaw = this.inner.doComplete(document, position, this.inner.parseStylesheet(document));
        return cssCompsRaw ? cssCompsRaw.items : [];
    }
    getDiagnostics(document) {
        if (!document.uri.endsWith('.css')) {
            return [];
        }
        const stylesheet = this.inner.parseStylesheet(document);
        return this.inner.doValidation(document, stylesheet)
            .filter(diag => {
            if (diag.code === 'emptyRules') {
                return false;
            }
            if (diag.code === 'css-unknownatrule' && readDocRange(document, diag.range) === '@custom-selector') {
                return false;
            }
            if (diag.code === 'css-lcurlyexpected' && readDocRange(document, vscode_languageserver_types_1.Range.create(vscode_languageserver_types_1.Position.create(diag.range.start.line, 0), diag.range.end)).startsWith('@custom-selector')) {
                return false;
            }
            if (diag.code === 'unknownProperties') {
                let prop = diag.message.match(/'(.*)'/)[1];
                let src = this.fs.loadTextFileSync(document.uri);
                let meta = provider_1.createMeta(src, document.uri).meta;
                if (meta && Object.keys(meta.mappedSymbols).some(ms => ms === prop)) {
                    return false;
                }
            }
            return true;
        })
            .map(diag => {
            diag.source = 'css';
            return diag;
        });
    }
    doHover(document, position) {
        const stylesheet = this.inner.parseStylesheet(document);
        return this.inner.doHover(document, position, stylesheet);
    }
    findReferences(document, position) {
        const stylesheet = this.inner.parseStylesheet(document);
        return this.inner.findReferences(document, position, stylesheet);
    }
    getColorPresentations(document, color, range) {
        const stylesheet = this.inner.parseStylesheet(document);
        return this.inner.getColorPresentations(document, stylesheet, color, range);
    }
    findColors(document) {
        const stylesheet = this.inner.parseStylesheet(document);
        return this.inner.findDocumentColors(document, stylesheet);
    }
    findColor(document) {
        const colors = this.findColors(document);
        return colors.length ? colors[0].color : null;
    }
}
exports.CssService = CssService;
//# sourceMappingURL=css-service.js.map